# Generated by roxygen2: do not edit by hand

export(rdf_add)
export(rdf_load)
export(rdf_load_file)
export(rdf_remove)
export(rdf_serialize)
export(rdf_size)
export(rdf_store)
export(rdf_store_dump)
export(rdf_store_insert)
export(rdf_store_load)
export(rdf_store_new)
export(rdf_store_open)
export(rdf_store_query)
export(rdf_store_remove)
export(rdf_store_size)
export(rdf_store_update)
export(sparql_query)
export(sparql_update)
useDynLib(roxigraph, .registration = TRUE)
