% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/store.R
\name{rdf_load}
\alias{rdf_load}
\title{Load RDF Data}
\usage{
rdf_load(store, data, format = "turtle", base_iri = NULL)
}
\arguments{
\item{store}{An RDF store handle}

\item{data}{RDF data as a character string}

\item{format}{RDF format: "turtle", "ntriples", "rdfxml", "nquads", or "trig"}

\item{base_iri}{Optional base IRI for resolving relative URIs}
}
\value{
Invisibly returns NULL
}
\description{
Loads RDF data into the store from a string.
}
\examples{
store <- rdf_store()
rdf_load(store, '<http://example.org/s> <http://example.org/p> "value" .', format = "ntriples")
}
