% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extendr-wrappers.R
\name{rdf_store_insert}
\alias{rdf_store_insert}
\title{Insert a triple into the store}
\usage{
rdf_store_insert(store_idx, subject, predicate, object, graph)
}
\arguments{
\item{store_idx}{Store index}

\item{subject}{Subject IRI (e.g., \code{"<http://example.org/s>"}) or blank node ("_:b1")}

\item{predicate}{Predicate IRI (e.g., \code{"<http://example.org/p>"})}

\item{object}{Object (IRI, blank node, or literal with quotes e.g., "\"value\"")}

\item{graph}{Optional graph name IRI}
}
\value{
No return value, called for side effects (inserting triples into the store)
}
\description{
Insert a triple into the store
}
\examples{
store <- rdf_store_new()
rdf_store_insert(store, "<http://example.org/s>", "<http://example.org/p>", '"val"', NULL)
}
\keyword{internal}
